@@ -48,8 +48,9 @@ from lollypop.database_artists import ArtistsDatabase
 from lollypop.database_genres import GenresDatabase
 from lollypop.database_tracks import TracksDatabase
 from lollypop.playlists import Playlists
-from lollypop.objects import Album
+from lollypop.objects import Album, Track
 from lollypop.collectionscanner import CollectionScanner
+from lollypop.lio import Lio
 
 
 class Application(Gtk.Application):
@@ -79,8 +80,8 @@ class Application(Gtk.Application):
         self.__init_proxy()
         GLib.set_application_name('Lollypop')
         GLib.set_prgname('lollypop')
-        self.add_main_option("album", b'a', GLib.OptionFlags.NONE,
-                             GLib.OptionArg.STRING, "Play album", None)
+        self.add_main_option("play-ids", b'a', GLib.OptionFlags.NONE,
+                             GLib.OptionArg.STRING, "Play ids", None)
         self.add_main_option("debug", b'd', GLib.OptionFlags.NONE,
                              GLib.OptionArg.NONE, "Debug lollypop", None)
         self.add_main_option("set-rating", b'r', GLib.OptionFlags.NONE,
@@ -111,10 +112,10 @@ class Application(Gtk.Application):
         """
         self.__is_fs = False
         if Gtk.get_minor_version() > 18:
-            cssProviderFile = Gio.File.new_for_uri(
+            cssProviderFile = Lio.File.new_for_uri(
                 'resource:///org/gnome/Lollypop/application.css')
         else:
-            cssProviderFile = Gio.File.new_for_uri(
+            cssProviderFile = Lio.File.new_for_uri(
                 'resource:///org/gnome/Lollypop/application-legacy.css')
         cssProvider = Gtk.CssProvider()
         cssProvider.load_from_file(cssProviderFile)
@@ -211,6 +212,9 @@ class Application(Gtk.Application):
                 else:
                     self.settings.set_value('network-search',
                                             GLib.Variant('b', False))
+            t = Thread(target=self.__preload_portal)
+            t.daemon = True
+            t.start()
 
     def prepare_to_exit(self, action=None, param=None):
         """
@@ -300,19 +304,34 @@ class Application(Gtk.Application):
 #######################
 # PRIVATE             #
 #######################
+    def __preload_portal(self):
+        """
+            Preload lollypop portal
+        """
+        try:
+            bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
+            Gio.DBusProxy.new_sync(bus, Gio.DBusProxyFlags.NONE, None,
+                                   'org.gnome.Lollypop.Portal',
+                                   '/org/gnome/LollypopPortal',
+                                   'org.gnome.Lollypop.Portal', None)
+        except:
+            pass
+
     def __init_proxy(self):
         """
             Init proxy setting env
         """
         try:
-            settings = Gio.Settings.new('org.gnome.system.proxy.http')
-            h = settings.get_value('host').get_string()
-            p = settings.get_value('port').get_int32()
-            if h != '' and p != 0:
-                GLib.setenv('http_proxy', "%s:%s" % (h, p), True)
-                GLib.setenv('https_proxy', "%s:%s" % (h, p), True)
-        except:
-            pass
+            proxy = Gio.Settings.new('org.gnome.system.proxy')
+            https = Gio.Settings.new('org.gnome.system.proxy.https')
+            mode = proxy.get_value('mode').get_string()
+            if mode != 'none':
+                h = https.get_value('host').get_string()
+                p = https.get_value('port').get_int32()
+                GLib.setenv('http_proxy', "http://%s:%s" % (h, p), True)
+                GLib.setenv('https_proxy', "http://%s:%s" % (h, p), True)
+        except Exception as e:
+            print("Application::__init_proxy()", e)
 
     def __on_command_line(self, app, app_cmd_line):
         """
@@ -331,15 +350,23 @@ class Application(Gtk.Application):
                 self.player.current_track.set_popularity(value)
         if options.contains('play-pause'):
             self.player.play_pause()
-        elif options.contains('album'):
+        elif options.contains('play-ids'):
             try:
-                value = options.lookup_value('album').get_string()
-                album_ids = value.split(';')
-                album = Album(int(album_ids.pop(0)))
-                self.player.play_album(album)
-                for album_id in album_ids:
-                    self.player.add_album(Album(int(album_id)))
-            except:
+                value = options.lookup_value('play-ids').get_string()
+                ids = value.split(';')
+                track_ids = []
+                for id in ids:
+                    if id[0:2] == "a:":
+                        album = Album(int(id[2:]))
+                        track_ids += album.track_ids
+                    else:
+                        track_ids.append(int(id[2:]))
+                track = Track(track_ids[0])
+                self.player.load(track)
+                self.player.populate_user_playlist_by_tracks(track_ids,
+                                                             [Type.SEARCH])
+            except Exception as e:
+                print(e)
                 pass
         elif options.contains('next'):
             self.player.next()
