@@ -15,6 +15,7 @@ from gi.repository import GLib, Gdk, GdkPixbuf, Gio
 import re
 
 from lollypop.art_base import BaseArt
+from lollypop.lio import Lio
 
 
 class RadioArt(BaseArt):
@@ -28,7 +29,7 @@ class RadioArt(BaseArt):
             Init radio art
         """
         BaseArt.__init__(self)
-        d = Gio.File.new_for_path(self._RADIOS_PATH)
+        d = Lio.File.new_for_path(self._RADIOS_PATH)
         if not d.query_exists():
             try:
                 d.make_directory_with_parents()
@@ -47,7 +48,7 @@ class RadioArt(BaseArt):
             cache_path_png = "%s/%s_%s.png" % (self._CACHE_PATH,
                                                filename,
                                                size)
-            f = Gio.File.new_for_path(cache_path_png)
+            f = Lio.File.new_for_path(cache_path_png)
             if f.query_exists():
                 return cache_path_png
             else:
@@ -77,7 +78,7 @@ class RadioArt(BaseArt):
 
         try:
             # Look in cache
-            f = Gio.File.new_for_path(cache_path_png)
+            f = Lio.File.new_for_path(cache_path_png)
             if f.query_exists():
                 pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(cache_path_png,
                                                                 size,
@@ -114,8 +115,8 @@ class RadioArt(BaseArt):
         """
         filename = self.__get_radio_cache_name(name)
         cache_path_png = "%s/%s_%s.png" % (self._CACHE_PATH, filename, size)
-        s = Gio.File.new_for_uri(uri)
-        d = Gio.File.new_for_path(cache_path_png)
+        s = Lio.File.new_for_uri(uri)
+        d = Lio.File.new_for_path(cache_path_png)
         s.copy(d, Gio.FileCopyFlags.OVERWRITE, None, None)
         GLib.idle_add(self.emit, 'radio-artwork-changed', name)
 
@@ -128,8 +129,8 @@ class RadioArt(BaseArt):
         old = "%s/%s.png" % (self._RADIOS_PATH, old_name)
         new = "%s/%s.png" % (self._RADIOS_PATH, new_name)
         try:
-            src = Gio.File.new_for_path(old)
-            dst = Gio.File.new_for_path(new)
+            src = Lio.File.new_for_path(old)
+            dst = Lio.File.new_for_path(new)
             src.move(dst, Gio.FileCopyFlags.OVERWRITE, None, None)
         except Exception as e:
             print("RadioArt::rename_radio(): %s" % e)
@@ -161,7 +162,7 @@ class RadioArt(BaseArt):
         """
         cache_name = self.__get_radio_cache_name(name)
         try:
-            f = Gio.File.new_for_path(self._CACHE_PATH)
+            f = Lio.File.new_for_path(self._CACHE_PATH)
             infos = f.enumerate_children(
                 'standard::name',
                 Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -185,7 +186,7 @@ class RadioArt(BaseArt):
         """
         try:
             name = name.replace('/', '-')
-            f = Gio.File.new_for_path(self._RADIOS_PATH + "/" + name + ".png")
+            f = Lio.File.new_for_path(self._RADIOS_PATH + "/" + name + ".png")
             if f.query_exists():
                 return self._RADIOS_PATH + "/" + name + ".png"
             return None
