@@ -28,6 +28,8 @@ class Codecs:
         """
             Install missing plugins
         """
+        if not GstPbutils.install_plugins_supported():
+            return
         try:
             context = GstPbutils.InstallPluginsContext.new()
             try:
@@ -43,7 +45,7 @@ class Codecs:
             GstPbutils.install_plugins_async(
                 details,
                 context,
-                self._null)
+                self.__null)
         except Exception as e:
             print("Codecs::__init__(): %s" % e)
 
@@ -65,5 +67,8 @@ class Codecs:
             return True
         return False
 
-    def _null(self, arg):
+#######################
+# PRIVATE             #
+#######################
+    def __null(self, arg):
         pass
