@@ -28,6 +28,7 @@ class AlbumsDatabase:
         """
             Init albums database object
         """
+        self.__max_count = 1
         self._cached_randoms = []
 
     def add(self, name, artist_ids, uri, popularity, mtime):
@@ -210,10 +211,11 @@ class AlbumsDatabase:
                 return v[0]
             return 0
 
-    def set_more_popular(self, album_id):
+    def set_more_popular(self, album_id, pop_to_add):
         """
             Increment popularity field for album id
-            @param int
+            @param album id as int
+            @param pop as int
             @raise sqlite3.OperationalError on db update
         """
         with SqlCursor(Lp().db) as sql:
@@ -224,7 +226,7 @@ class AlbumsDatabase:
                 current = pop[0]
             else:
                 current = 0
-            current += 1
+            current += pop_to_add
             sql.execute("UPDATE albums set popularity=? WHERE rowid=?",
                         (current, album_id))
             sql.commit()
@@ -384,15 +386,32 @@ class AlbumsDatabase:
     def get_uri_count(self, uri):
         """
             Count album having uri as album uri
+            @param uri as str
+            @return count as int
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT count(uri) FROM albums WHERE uri=?",
+            result = sql.execute("SELECT COUNT(uri) FROM albums WHERE uri=?",
                                  (uri,))
             v = result.fetchone()
             if v is not None:
                 return v[0]
             return 1
 
+    def get_tracks_count(self, album_id):
+        """
+            Return tracks count
+            @param album id as int
+            @return count as int
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT COUNT(tracks.rowid)\
+                                  FROM tracks WHERE album_id=?",
+                                 (album_id,))
+            v = result.fetchone()
+            if v is not None:
+                return v[0]
+            return 1
+
     def get_populars(self):
         """
             Get albums ids with popularity
@@ -920,6 +939,28 @@ class AlbumsDatabase:
                 sql.execute("DELETE FROM albums WHERE rowid=?", (album_id,))
             return ret
 
+    @property
+    def max_count(self):
+        """
+            Get MAX(COUNT(tracks)) for albums
+        """
+        return self.__max_count
+
+    def update_max_count(self):
+        """
+            Update MAX(COUNT(tracks)) for albums
+        """
+        with SqlCursor(Lp().db) as sql:
+            result = sql.execute("SELECT MAX(num_tracks)\
+                                  FROM (SELECT COUNT(t.rowid)\
+                                  AS num_tracks FROM albums\
+                                  INNER JOIN tracks t\
+                                  ON albums.rowid=t.album_id\
+                                  GROUP BY albums.rowid)")
+            v = result.fetchone()
+            if v:
+                self.__max_count = v[0]
+
 #######################
 # PRIVATE             #
 #######################
