@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GLib, Gio
+from gi.repository import GLib
 
 from threading import Thread
 import json
@@ -18,6 +18,7 @@ import json
 from lollypop.cache import InfoCache
 from lollypop.define import Lp, GOOGLE_API_ID, Type
 from lollypop.utils import debug, get_network_available
+from lollypop.lio import Lio
 
 
 class Downloader:
@@ -78,30 +79,24 @@ class Downloader:
         cs_api_key = Lp().settings.get_value('cs-api-key').get_string()
 
         try:
-            f = Gio.File.new_for_uri("https://www.googleapis.com/"
+            f = Lio.File.new_for_uri("https://www.googleapis.com/"
                                      "customsearch/v1?key=%s&cx=%s"
                                      "&q=%s&searchType=image" %
                                      (cs_api_key,
                                       GOOGLE_API_ID,
-                                      GLib.uri_escape_string(search,
-                                                             "",
-                                                             False)))
+                                      Lio.uri_escape_string(search,
+                                                            "",
+                                                            False)))
 
             (status, data, tag) = f.load_contents()
-            if not status:
-                return []
+            if status:
+                decode = json.loads(data.decode('utf-8'))
+                if decode is None:
+                    return urls
+                for item in decode['items']:
+                    urls.append(item['link'])
         except Exception as e:
             print(e)
-            return []
-        try:
-            decode = json.loads(data.decode('utf-8'))
-            if decode is None:
-                return urls
-            for item in decode['items']:
-                urls.append(item['link'])
-        except:
-            pass
-
         return urls
 
 #######################
@@ -137,9 +132,9 @@ class Downloader:
             @return (url as str/None, content as None)
         """
         try:
-            artist_formated = GLib.uri_escape_string(
+            artist_formated = Lio.uri_escape_string(
                                 artist, None, True).replace(' ', '+')
-            s = Gio.File.new_for_uri("https://api.deezer.com/search/artist/?"
+            s = Lio.File.new_for_uri("https://api.deezer.com/search/artist/?"
                                      "q=%s&output=json&index=0&limit=1&" %
                                      artist_formated)
             (status, data, tag) = s.load_contents()
@@ -158,9 +153,9 @@ class Downloader:
             @return (url as str/None, content as None)
         """
         try:
-            artist_formated = GLib.uri_escape_string(
+            artist_formated = Lio.uri_escape_string(
                                 artist, None, True).replace(' ', '+')
-            s = Gio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
+            s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
                                      "&type=artist" % artist_formated)
             (status, data, tag) = s.load_contents()
             if status:
@@ -183,8 +178,8 @@ class Downloader:
         """
         image = None
         try:
-            album_formated = GLib.uri_escape_string(album, None, True)
-            s = Gio.File.new_for_uri("https://api.deezer.com/search/album/?"
+            album_formated = Lio.uri_escape_string(album, None, True)
+            s = Lio.File.new_for_uri("https://api.deezer.com/search/album/?"
                                      "q=%s&output=json" %
                                      album_formated)
             (status, data, tag) = s.load_contents()
@@ -196,7 +191,7 @@ class Downloader:
                         url = item['cover_xl']
                         break
                 if url is not None:
-                    s = Gio.File.new_for_uri(url)
+                    s = Lio.File.new_for_uri(url)
                     (status, image, tag) = s.load_contents()
         except Exception as e:
             print("Downloader::__get_deezer_album_artwork: %s" % e)
@@ -213,9 +208,9 @@ class Downloader:
         image = None
         artists_spotify_ids = []
         try:
-            artist_formated = GLib.uri_escape_string(
+            artist_formated = Lio.uri_escape_string(
                                 artist, None, True).replace(' ', '+')
-            s = Gio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
+            s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
                                      "&type=artist" % artist_formated)
             (status, data, tag) = s.load_contents()
             if status:
@@ -224,7 +219,7 @@ class Downloader:
                     artists_spotify_ids.append(item['id'])
 
             for artist_spotify_id in artists_spotify_ids:
-                s = Gio.File.new_for_uri("https://api.spotify.com/v1/artists/"
+                s = Lio.File.new_for_uri("https://api.spotify.com/v1/artists/"
                                          "%s/albums" % artist_spotify_id)
                 (status, data, tag) = s.load_contents()
                 if status:
@@ -236,7 +231,7 @@ class Downloader:
                             break
 
                     if url is not None:
-                        s = Gio.File.new_for_uri(url)
+                        s = Lio.File.new_for_uri(url)
                         (status, image, tag) = s.load_contents()
                     break
         except Exception as e:
@@ -254,9 +249,9 @@ class Downloader:
         """
         image = None
         try:
-            album_formated = GLib.uri_escape_string(
+            album_formated = Lio.uri_escape_string(
                                 album, None, True).replace(' ', '+')
-            s = Gio.File.new_for_uri("https://itunes.apple.com/search"
+            s = Lio.File.new_for_uri("https://itunes.apple.com/search"
                                      "?entity=album&term=%s" % album_formated)
             (status, data, tag) = s.load_contents()
             if status:
@@ -265,7 +260,7 @@ class Downloader:
                     if item['artistName'].lower() == artist.lower():
                         url = item['artworkUrl60'].replace('60x60',
                                                            '512x512')
-                        s = Gio.File.new_for_uri(url)
+                        s = Lio.File.new_for_uri(url)
                         (status, image, tag) = s.load_contents()
                         break
         except Exception as e:
@@ -287,7 +282,7 @@ class Downloader:
                 last_album = Lp().lastfm.get_album(artist, album)
                 url = last_album.get_cover_image(4)
                 if url is not None:
-                    s = Gio.File.new_for_uri(url)
+                    s = Lio.File.new_for_uri(url)
                     (status, image, tag) = s.load_contents()
             except Exception as e:
                 print("Downloader::_get_album_art_lastfm: %s [%s/%s]" %
@@ -318,7 +313,7 @@ class Downloader:
                     method = getattr(self, helper)
                     (url, content) = method(artist)
                     if url is not None:
-                        s = Gio.File.new_for_uri(url)
+                        s = Lio.File.new_for_uri(url)
                         (status, data, tag) = s.load_contents()
                         if status:
                             artwork_set = True
