@@ -465,7 +465,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
                 self._prev_track = LinearPlayer.prev(self)
             self.emit('prev-changed')
         except Exception as e:
-            print("Player::set_prev", e)
+            print("Player::set_prev():", e)
 
     def set_next(self, force=False):
         """
@@ -507,18 +507,18 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             self._next_track = next_track
             self.emit('next-changed')
         except Exception as e:
-            print("Player::set_next", e)
+            print("Player::set_next():", e)
 
     def skip_album(self):
         """
             Skip current album
         """
         # In party or shuffle, just update next track
-        if Lp().player.is_party or\
+        if self.is_party or\
                 Lp().settings.get_enum('shuffle') == Shuffle.TRACKS:
-            Lp().player.set_next()
+            self.set_next()
             # We send this signal to update next popover
-            Lp().player.emit('queue-changed')
+            self.emit('queue-changed')
         elif self._current_track.id is not None:
             pos = self._albums.index(self._current_track.album.id)
             if pos + 1 >= len(self._albums):
