@@ -293,7 +293,7 @@ class BinPlayer(BasePlayer):
             self.emit('current-changed')
             if Lp().notify is not None:
                 Lp().notify.send(str(e), track.uri)
-            print("PlayerBin::__get_youtube_uri()", e)
+            print("PlayerBin::_load_web()", e)
 
     def _scrobble(self, finished, finished_start_time):
         """
@@ -431,9 +431,23 @@ class BinPlayer(BasePlayer):
         # No cossfading if we need to stop
         if self.__need_to_stop() and next:
             return
-        if self._playbin.query_position(Gst.Format.TIME)[1] / 1000000000 >\
-                self.current_track.duration - 10:
+
+        if track is None:
             self._scrobble(self.current_track, self._start_time)
+            # Increment popularity
+            if not Lp().scanner.is_locked():
+                Lp().tracks.set_more_popular(self.current_track.id)
+                # In party mode, linear popularity
+                if self.is_party:
+                    pop_to_add = 1
+                # In normal mode, based on tracks count
+                else:
+                    pop_to_add = int(Lp().albums.max_count /
+                                     Lp().albums.get_tracks_count(
+                                                  self.current_track.album_id))
+                Lp().albums.set_more_popular(self.current_track.album_id,
+                                             pop_to_add)
+
         GLib.idle_add(self.__volume_down, self._playbin,
                       self._plugins, duration)
         if self._playbin == self.__playbin2:
@@ -583,21 +597,27 @@ class BinPlayer(BasePlayer):
             @param playbin as Gst bin
         """
         debug("Player::__on_stream_about_to_finish(): %s" % playbin)
-        # Don't do anything if crossfade on
+        # Don't do anything if crossfade on, track already changed
         if self._crossfading:
             return
         if self.current_track.id == Type.RADIOS:
             return
-        # For Last.fm scrobble
-        finished = self.current_track
-        finished_start_time = self._start_time
-        if self._next_track.id is not None:
-            self._load_track(self._next_track)
-        self._scrobble(finished, finished_start_time)
+        self._scrobble(self.current_track, self._start_time)
         # Increment popularity
         if not Lp().scanner.is_locked():
-            Lp().tracks.set_more_popular(finished.id)
-            Lp().albums.set_more_popular(finished.album_id)
+            Lp().tracks.set_more_popular(self.current_track.id)
+            # In party mode, linear popularity
+            if self.is_party:
+                pop_to_add = 1
+            # In normal mode, based on tracks count
+            else:
+                pop_to_add = int(Lp().albums.max_count /
+                                 Lp().albums.get_tracks_count(
+                                                  self.current_track.album_id))
+            Lp().albums.set_more_popular(self.current_track.album_id,
+                                         pop_to_add)
+        if self._next_track.id is not None:
+            self._load_track(self._next_track)
 
     def __set_gv_uri(self, uri, track, play):
         """
