@@ -12,12 +12,11 @@
 
 from gi.repository import Gtk, GLib, Gdk, Pango, GObject
 
-from cgi import escape
 from gettext import gettext as _
 
 from lollypop.pop_album import AlbumPopover
 from lollypop.view import LazyLoadingView
-from lollypop.define import Lp, ArtSize, NextContext
+from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album
 
 
@@ -76,9 +75,11 @@ class AlbumRow(Gtk.ListBoxRow):
         row_widget.set_margin_end(self.__MARGIN)
         grid = Gtk.Grid()
         grid.set_column_spacing(8)
-        self.__artist_label = Gtk.Label.new("<b>%s</b>" %
-                                            escape(", ".join(
-                                                        self.__album.artists)))
+        if self.__album.artists:
+            artists = GLib.markup_escape_text(", ".join(self.__album.artists))
+        else:
+            artists = _("Compilation")
+        self.__artist_label = Gtk.Label.new("<b>%s</b>" % artists)
         self.__artist_label.set_use_markup(True)
         self.__artist_label.set_hexpand(True)
         self.__artist_label.set_property('halign', Gtk.Align.START)
@@ -238,9 +239,7 @@ class AlbumRow(Gtk.ListBoxRow):
         if Lp().player.current_track.album.id == self.__album.id:
             # If not last album, skip it
             if len(Lp().player.get_albums()) > 1:
-                Lp().player.set_next_context(NextContext.START_NEW_ALBUM)
-                Lp().player.set_next()
-                Lp().player.next()
+                Lp().player.skip_album()
                 Lp().player.remove_album(self.__album)
             # remove it and stop playback by going to next track
             else:
@@ -263,8 +262,8 @@ class AlbumRow(Gtk.ListBoxRow):
         layout_title = self.__title_label.get_layout()
         layout_artist = self.__artist_label.get_layout()
         if layout_title.is_ellipsized() or layout_artist.is_ellipsized():
-            artist = escape(self.__artist_label.get_text())
-            title = escape(self.__title_label.get_text())
+            artist = GLib.markup_escape_text(self.__artist_label.get_text())
+            title = GLib.markup_escape_text(self.__title_label.get_text())
             self.set_tooltip_markup("<b>%s</b>\n%s" % (artist, title))
         else:
             self.set_tooltip_text('')
