@@ -20,6 +20,7 @@ from lollypop.objects import Track
 from lollypop.widgets_rating import RatingWidget
 from lollypop.define import Lp, ArtSize
 from lollypop.art import Art
+from lollypop.lio import Lio
 
 
 # Show a popover with radio logos from the web
@@ -121,7 +122,7 @@ class RadioPopover(Gtk.Popover):
             url = self._urls.pop()
             stream = None
             try:
-                f = Gio.File.new_for_uri(url)
+                f = Lio.File.new_for_uri(url)
                 (status, data, tag) = f.load_contents()
                 if status:
                     stream = Gio.MemoryInputStream.new_from_data(data, None)
@@ -234,7 +235,7 @@ class RadioPopover(Gtk.Popover):
             store = Art._RADIOS_PATH
             self.__radios_manager.delete(self.__name)
             Lp().art.clean_radio_cache(self.__name)
-            f = Gio.File.new_for_path(store + "/%s.png" % self.__name)
+            f = Lio.File.new_for_path(store + "/%s.png" % self.__name)
             if f.query_exists():
                 f.delete()
 
