@@ -20,6 +20,7 @@ from lollypop.objects import Track, Album
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
 from lollypop.pop_album import AlbumPopover
 from lollypop.utils import noaccents, get_network_available
+from lollypop.lio import Lio
 
 
 class SearchRow(Gtk.ListBoxRow):
@@ -434,7 +435,7 @@ class SearchPopover(Gtk.Popover):
             @param row as SearchRow
         """
         try:
-            f = Gio.File.new_for_uri(uri)
+            f = Lio.File.new_for_uri(uri)
             (status, data, tag) = f.load_contents(None)
             if status:
                 stream = Gio.MemoryInputStream.new_from_data(data,
@@ -565,8 +566,8 @@ class SearchPopover(Gtk.Popover):
             history = "♫" + item.name + item.artists[0]
         else:
             history = item.name + item.artists[0]
-        if history not in self.__history:
-            self.__history.append(history)
+        if history.lower() not in self.__history:
+            self.__history.append(history.lower())
             search_row = SearchRow(item, False)
             search_row.show()
             self.__view.add(search_row)
@@ -631,10 +632,6 @@ class SearchPopover(Gtk.Popover):
                     row.destroy()
                 else:
                     Lp().player.load(Track(row.id))
-            elif Gtk.get_minor_version() > 16:
-                popover = AlbumPopover(row.id, [], [])
-                popover.set_relative_to(row)
-                popover.show()
             else:
                 t = Thread(target=self.__play_search, args=(row.id,
                                                             row.is_track))
