@@ -20,7 +20,6 @@ except:
 from gettext import gettext as _
 from gettext import ngettext as ngettext
 from threading import Thread
-from re import findall, DOTALL
 
 from lollypop.define import Lp, SecretSchema, SecretAttributes, Type
 from lollypop.cache import InfoCache
@@ -28,6 +27,7 @@ from lollypop.database import Database
 from lollypop.touch_helper import TouchHelper
 from lollypop.database_history import History
 from lollypop.utils import get_network_available
+from lollypop.lio import Lio
 
 
 class Settings(Gio.Settings):
@@ -150,7 +150,21 @@ class SettingsDialog:
         switch_librefm.set_state(Lp().settings.get_value('use-librefm'))
 
         switch_artwork_tags = builder.get_object('switch_artwork_tags')
-        if GLib.find_program_in_path("kid3-cli") is None:
+        # Check portal for kid3-cli
+        can_set_cover = False
+        try:
+            bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
+            proxy = Gio.DBusProxy.new_sync(bus, Gio.DBusProxyFlags.NONE, None,
+                                           'org.gnome.Lollypop.Portal',
+                                           '/org/gnome/LollypopPortal',
+                                           'org.gnome.Lollypop.Portal', None)
+            can_set_cover = proxy.call_sync('CanSetCover', None,
+                                            Gio.DBusCallFlags.NO_AUTO_START,
+                                            500, None)[0]
+        except Exception as e:
+            print("You are missing lollypop-portal: "
+                  "https://github.com/gnumdk/lollypop-portal", e)
+        if not can_set_cover:
             grid = builder.get_object('grid_behaviour')
             h = grid.child_get_property(switch_artwork_tags, 'height')
             w = grid.child_get_property(switch_artwork_tags, 'width')
@@ -540,18 +554,19 @@ class SettingsDialog:
             @return name/device as [(str, str)]
         """
         ret = []
-        argv = ["pacmd", "list-sinks", None]
         try:
-            (s, out, err, e) = GLib.spawn_sync(None, argv, None,
-                                               GLib.SpawnFlags.SEARCH_PATH,
-                                               None)
-            string = out.decode('utf-8')
-            devices = findall('name: <([^>]*)>', string, DOTALL)
-            names = findall('device.description = "([^"]*)"', string, DOTALL)
-            for name in names:
-                ret.append((name, devices.pop(0)))
+            bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
+            proxy = Gio.DBusProxy.new_sync(bus, Gio.DBusProxyFlags.NONE, None,
+                                           'org.gnome.Lollypop.Portal',
+                                           '/org/gnome/LollypopPortal',
+                                           'org.gnome.Lollypop.Portal', None)
+            ret = proxy.call_sync('PaListSinks', None,
+                                  Gio.DBusCallFlags.NO_AUTO_START,
+                                  500, None)
+            return ret[0]
         except Exception as e:
-            print("SettingsDialog::_get_pa_outputse()", e)
+            print("You are missing lollypop-portal: "
+                  "https://github.com/gnumdk/lollypop-portal", e)
         return ret
 
     def __set_outputs(self, combo):
@@ -680,7 +695,7 @@ class SettingsDialog:
         if track_ids:
             track_id = track_ids.pop(0)
             uri = Lp().tracks.get_uri(track_id)
-            f = Gio.File.new_for_uri(uri)
+            f = Lio.File.new_for_uri(uri)
             name = f.get_basename()
             album_id = Lp().tracks.get_album_id(track_id)
             popularity = Lp().tracks.get_popularity(track_id)
