@@ -18,6 +18,7 @@ from re import match
 from lollypop.utils import escape, debug
 from lollypop.define import Lp, Type
 from lollypop.objects import Track
+from lollypop.lio import Lio
 
 
 # TODO Rework this code: was designed
@@ -119,7 +120,7 @@ class MtpSync:
             self.__remove_empty_dirs()
 
             # Remove old playlists
-            d = Gio.File.new_for_uri(self._uri)
+            d = Lio.File.new_for_uri(self._uri)
             infos = d.enumerate_children(
                 'standard::name',
                 Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -130,7 +131,7 @@ class MtpSync:
                     f = infos.get_child(info)
                     self.__retry(f.delete, (None,))
 
-            d = Gio.File.new_for_uri(self._uri+"/unsync")
+            d = Lio.File.new_for_uri(self._uri+"/unsync")
             if not d.query_exists():
                 self.__retry(d.make_directory_with_parents, (None,))
         except Exception as e:
@@ -178,7 +179,7 @@ class MtpSync:
             # First get all directories
             while dir_uris:
                 uri = dir_uris.pop(0)
-                d = Gio.File.new_for_uri(uri)
+                d = Lio.File.new_for_uri(uri)
                 infos = d.enumerate_children(
                     'standard::name,standard::type',
                     Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -188,7 +189,7 @@ class MtpSync:
                         if info.get_name() != "unsync":
                             f = infos.get_child(info)
                             # We need to check for dir to be empty
-                            # On some device, Gio.File.delete() remove
+                            # On some device, Lio.File.delete() remove
                             # non empty directories #828
                             subinfos = f.enumerate_children(
                                     'standard::name,standard::type',
@@ -203,7 +204,7 @@ class MtpSync:
                                 to_delete.append(f.get_uri())
             # Then delete
             for d in to_delete:
-                d = Gio.File.new_for_uri(d)
+                d = Lio.File.new_for_uri(d)
                 try:
                     d.delete()
                 except:
@@ -218,13 +219,13 @@ class MtpSync:
         """
         children = []
         dir_uris = [self._uri]
-        d = Gio.File.new_for_uri(self._uri)
+        d = Lio.File.new_for_uri(self._uri)
         if not d.query_exists():
             self.__retry(d.make_directory_with_parents, (None,))
         while dir_uris:
             try:
                 uri = dir_uris.pop(0)
-                d = Gio.File.new_for_uri(uri)
+                d = Lio.File.new_for_uri(uri)
                 infos = d.enumerate_children(
                     'standard::name,standard::type',
                     Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
@@ -254,7 +255,7 @@ class MtpSync:
                 try:
                     playlist_name = Lp().playlists.get_name(playlist)
                     # Create playlist
-                    m3u = Gio.File.new_for_path(
+                    m3u = Lio.File.new_for_path(
                         "/tmp/lollypop_%s.m3u" % (playlist_name,))
                     self.__retry(m3u.replace_contents, (b'#EXTM3U\n', None,
                                  False,
@@ -296,24 +297,24 @@ class MtpSync:
                                            artists,
                                            album_name)
 
-                d = Gio.File.new_for_uri(on_device_album_uri)
+                d = Lio.File.new_for_uri(on_device_album_uri)
                 if not d.query_exists():
                     self.__retry(d.make_directory_with_parents, (None,))
                 # Copy album art
                 art = Lp().art.get_album_artwork_uri(track.album)
                 debug("MtpSync::__copy_to_device(): %s" % art)
                 if art is not None:
-                    src_art = Gio.File.new_for_uri(art)
+                    src_art = Lio.File.new_for_uri(art)
                     art_uri = "%s/cover.jpg" % on_device_album_uri
                     # To be sure to get uri correctly escaped for Gio
-                    f = Gio.File.new_for_uri(art_uri)
+                    f = Lio.File.new_for_uri(art_uri)
                     self.__copied_art_uris.append(f.get_uri())
-                    dst_art = Gio.File.new_for_uri(art_uri)
+                    dst_art = Lio.File.new_for_uri(art_uri)
                     if not dst_art.query_exists():
                         self.__retry(src_art.copy,
                                      (dst_art, Gio.FileCopyFlags.OVERWRITE,
                                       None, None))
-                f = Gio.File.new_for_uri(track.uri)
+                f = Lio.File.new_for_uri(track.uri)
                 track_name = f.get_basename()
                 # Check extension, if not mp3, convert
                 m = match('.*(\.[^.]*)', track.uri)
@@ -323,7 +324,7 @@ class MtpSync:
                     track_name = track_name.replace(ext, ".mp3")
                 else:
                     convertion_needed = False
-                src_track = Gio.File.new_for_uri(track.uri)
+                src_track = Lio.File.new_for_uri(track.uri)
                 info = src_track.query_info('time::modified',
                                             Gio.FileQueryInfoFlags.NONE,
                                             None)
@@ -345,11 +346,11 @@ class MtpSync:
                                  track_name)
                     self.__retry(stream.get_output_stream().write,
                                  (line.encode(encoding='UTF-8'), None))
-                dst_track = Gio.File.new_for_uri(dst_uri)
+                dst_track = Lio.File.new_for_uri(dst_uri)
                 if not dst_track.query_exists():
                     if convertion_needed:
                         mp3_uri = "file:///tmp/%s" % track_name
-                        mp3_file = Gio.File.new_for_uri(mp3_uri)
+                        mp3_file = Lio.File.new_for_uri(mp3_uri)
                         pipeline = self.__convert_to_mp3(src_track, mp3_file)
                         # Check if encoding is finished
                         if pipeline is not None:
@@ -384,7 +385,7 @@ class MtpSync:
                 stream.close()
             if m3u is not None:
                 playlist_name = escape(playlist_name)
-                dst = Gio.File.new_for_uri(self._uri+'/'+playlist_name+'.m3u')
+                dst = Lio.File.new_for_uri(self._uri+'/'+playlist_name+'.m3u')
                 self.__retry(m3u.move,
                              (dst, Gio.FileCopyFlags.OVERWRITE, None, None))
 
@@ -423,14 +424,14 @@ class MtpSync:
                 on_device_album_uri = "%s/%s_%s" % (self._uri,
                                                     artists,
                                                     album_name)
-            f = Gio.File.new_for_uri(track.uri)
+            f = Lio.File.new_for_uri(track.uri)
             track_name = f.get_basename()
             # Check extension, if not mp3, convert
             m = match('.*(\.[^.]*)', track.uri)
             ext = m.group(1)
             if ext != ".mp3" and self.__convert:
                 track_name = track_name.replace(ext, ".mp3")
-            on_disk = Gio.File.new_for_uri(track.uri)
+            on_disk = Lio.File.new_for_uri(track.uri)
             info = on_disk.query_info('time::modified',
                                       Gio.FileQueryInfoFlags.NONE,
                                       None)
@@ -438,7 +439,7 @@ class MtpSync:
             mtime = info.get_attribute_as_string('time::modified')
             dst_uri = "%s/%s_%s" % (on_device_album_uri, mtime, track_name)
             # To be sure to get uri correctly escaped for Gio
-            f = Gio.File.new_for_uri(dst_uri)
+            f = Lio.File.new_for_uri(dst_uri)
             track_uris.append(f.get_uri())
 
         on_mtp_files = self.__get_track_files()
@@ -452,7 +453,7 @@ class MtpSync:
             debug("MtpSync::__remove_from_device(): %s" % uri)
             if uri not in track_uris and uri not in self.__copied_art_uris:
                 debug("MtpSync::__remove_from_device(): deleting %s" % uri)
-                to_delete = Gio.File.new_for_uri(uri)
+                to_delete = Lio.File.new_for_uri(uri)
                 self.__retry(to_delete.delete, (None,))
             self.__done += 1
             self._fraction = self.__done/self.__total
