@@ -129,11 +129,11 @@ class ToolbarInfo(Gtk.Bin, InfosController):
             @param args as []
         """
         if Lp().player.current_track.id >= 0:
-            from lollypop.pop_menu import PopToolbarMenu
+            from lollypop.pop_menu import PlaylistsMenu
             from lollypop.pop_menu import TrackMenuPopover
             popover = TrackMenuPopover(
                         Lp().player.current_track,
-                        PopToolbarMenu(Lp().player.current_track.id))
+                        PlaylistsMenu(Lp().player.current_track))
             popover.set_relative_to(self._infobox)
             popover.show()
 
@@ -202,8 +202,6 @@ class ToolbarInfo(Gtk.Bin, InfosController):
             @param keyboard as bool
             @param tooltip as Gtk.Tooltip
         """
-        # Can't add a \n in markup
-        # GTK bug => https://bugzilla.gnome.org/show_bug.cgi?id=749965
         layout_title = self._title_label.get_layout()
         layout_artist = self._artist_label.get_layout()
         if layout_title.is_ellipsized() or layout_artist.is_ellipsized():
