@@ -33,6 +33,7 @@ class AlbumsView(LazyLoadingView):
         """
         LazyLoadingView.__init__(self, True)
         self.__signal = None
+        self.__current = None
         self.__context_album_id = None
         self.__genre_ids = genre_ids
         self.__artist_ids = artist_ids
@@ -106,6 +107,14 @@ class AlbumsView(LazyLoadingView):
             @param flowbox as Gtk.Flowbox
             @param album_widget as AlbumSimpleWidget
         """
+        # Here some code for touch screens
+        # If mouse pointer activate Gtk.FlowBoxChild, overlay is on,
+        # as enter notify event enabled it
+        # Else, we are in touch screen, first time show overlay, next time
+        # show popover
+        if not album_widget.is_overlay:
+            album_widget.show_overlay(True)
+            return
         cover = album_widget.get_cover()
         if cover is None:
             return
@@ -121,7 +130,7 @@ class AlbumsView(LazyLoadingView):
             if self.__genre_ids and self.__genre_ids[0] == Type.CHARTS:
                 popover = AlbumMenuPopover(album, None)
                 popover.set_relative_to(cover)
-            elif album.is_youtube:
+            elif album.is_web:
                 popover = AlbumMenuPopover(album, AlbumMenu(album, True))
                 popover.set_relative_to(cover)
             else:
@@ -149,12 +158,14 @@ class AlbumsView(LazyLoadingView):
             popover.set_position(Gtk.PositionType.BOTTOM)
         album_widget.show_overlay(False)
         album_widget.lock_overlay(True)
-        popover.connect('closed', self.__on_popover_closed, album_widget)
+        popover.connect('closed', self.__on_album_popover_closed, album_widget)
         popover.show()
+        self.__current = album_widget
         cover.set_opacity(0.9)
 
-    def __on_popover_closed(self, popover, album_widget):
+    def __on_album_popover_closed(self, popover, album_widget):
         """
+            Remove overlay and restore opacity
             @param popover as Gtk.Popover
             @param album_widget as AlbumWidget
         """
