@@ -22,6 +22,7 @@ from lollypop.pop_info import InfoPopover
 from lollypop.cache import InfoCache
 from lollypop.pop_artwork import ArtworkPopover
 from lollypop.view_artist_albums import ArtistAlbumsView
+from lollypop.lio import Lio
 
 
 class ArtistView(ArtistAlbumsView):
@@ -51,9 +52,12 @@ class ArtistView(ArtistAlbumsView):
         self.__add_button = builder.get_object('add-button')
         self.__play_button = builder.get_object('play-button')
         self.__grid = builder.get_object('header')
-        if Lp().lastfm is None or\
-                not get_network_available():
+        if Lp().lastfm is None:
             builder.get_object('lastfm-button').hide()
+        elif not get_network_available():
+            builder.get_object('lastfm-button').set_sensitive(False)
+            builder.get_object('lastfm-button').set_tooltip_text(
+                                                  _("Network access disabled"))
         self._overlay.add_overlay(self.__grid)
         self.__empty = Gtk.Grid()
         self.__empty.show()
@@ -261,6 +265,16 @@ class ArtistView(ArtistAlbumsView):
         ArtistAlbumsView._on_current_changed(self, player)
         self.__update_jump_button()
 
+    def _on_populated(self, widget, widgets, scroll_value):
+        """
+            Set jump button state
+            @param widget as AlbumDetailedWidget
+            @param widgets as pending AlbumDetailedWidgets
+            @param scroll value as float
+        """
+        self.__update_jump_button()
+        ArtistAlbumsView._on_populated(self, widget, widgets, scroll_value)
+
 #######################
 # PRIVATE             #
 #######################
@@ -277,7 +291,7 @@ class ArtistView(ArtistAlbumsView):
                 for suffix in ["lastfm", "spotify", "wikipedia"]:
                     uri = InfoCache.get_artwork(artist, suffix, size)
                     if uri is not None:
-                        f = Gio.File.new_for_path(uri)
+                        f = Lio.File.new_for_path(uri)
                         (status, data, tag) = f.load_contents(None)
                         stream = Gio.MemoryInputStream.new_from_data(data,
                                                                      None)
@@ -417,13 +431,3 @@ class ArtistView(ArtistAlbumsView):
         if prefix == artist:
             self.__artwork.clear()
             self.__set_artwork()
-
-    def __on_populated(self, widget, widgets, scroll_value):
-        """
-            Set jump button state
-            @param widget as AlbumDetailedWidget
-            @param widgets as pending AlbumDetailedWidgets
-            @param scroll value as float
-        """
-        self.__update_jump_button()
-        ArtistAlbumsView._on_populated(self, widget, widgets, scroll_value)
