@@ -122,6 +122,20 @@ class ArtistAlbumsView(LazyLoadingView):
             for box in child.boxes:
                 box.invalidate_filter()
 
+    def _on_populated(self, widget, widgets, scroll_value):
+        """
+            Add another album/disc
+            @param widget as AlbumDetailedWidget
+            @param widgets as pending AlbumDetailedWidgets
+            @param scroll value as float
+        """
+        if not widget.is_populated():
+            widget.populate()
+        elif not self._stop:
+            GLib.idle_add(self.lazy_loading, widgets, scroll_value)
+        else:
+            self._stop = False
+
     def _get_children(self):
         """
             Return view children
@@ -153,7 +167,7 @@ class ArtistAlbumsView(LazyLoadingView):
         elif self._lazy_queue:
             widget = self._lazy_queue.pop(0)
         if widget is not None:
-            widget.connect('populated', self.__on_populated,
+            widget.connect('populated', self._on_populated,
                            widgets, scroll_value)
             widget.populate()
 
@@ -181,20 +195,6 @@ class ArtistAlbumsView(LazyLoadingView):
             self.emit('populated')
             GLib.idle_add(self.lazy_loading)
 
-    def __on_populated(self, widget, widgets, scroll_value):
-        """
-            Add another album/disc
-            @param widget as AlbumDetailedWidget
-            @param widgets as pending AlbumDetailedWidgets
-            @param scroll value as float
-        """
-        if not widget.is_populated():
-            widget.populate()
-        elif not self._stop:
-            GLib.idle_add(self.lazy_loading, widgets, scroll_value)
-        else:
-            self._stop = False
-
 
 class CurrentArtistAlbumsView(ViewContainer):
     """
@@ -216,7 +216,7 @@ class CurrentArtistAlbumsView(ViewContainer):
             @param track as Track
             @thread safe
         """
-        if track.album.artist_ids != self.__track.album.artist_ids:
+        if track.artist_ids != self.__track.artist_ids:
             self.__track = track
             albums = self.__get_albums()
             GLib.idle_add(self.__populate, albums)
@@ -267,7 +267,7 @@ class CurrentArtistAlbumsView(ViewContainer):
         self.clean_old_views(view)
 
         # Populate artist albums view
-        view = ArtistAlbumsView(self.__track.album.artist_ids, [])
+        view = ArtistAlbumsView(self.__track.artist_ids, [])
         view.connect('populated', self.__on_populated, spinner)
         view.show()
         view.populate(albums)
@@ -277,13 +277,13 @@ class CurrentArtistAlbumsView(ViewContainer):
             Get albums
             @return album ids as [int]
         """
+        albums = []
         if self.__track.album.artist_ids[0] == Type.COMPILATIONS:
-            albums = [self.__track.album.id]
-        else:
-            albums = Lp().artists.get_albums(self.__track.album.artist_ids)
-            # Charts album playing
-            if Lp().player.current_track.album.id not in albums:
-                albums.append(Lp().player.current_track.album.id)
+            albums += [self.__track.album.id]
+        albums += Lp().artists.get_albums(self.__track.artist_ids)
+        # Charts album playing
+        if Lp().player.current_track.album.id not in albums:
+            albums.append(Lp().player.current_track.album.id)
         return albums
 
     def __on_populated(self, view, spinner):
